Index: chrome/browser/net/url_request_mock_http_job.cc |
diff --git a/chrome/browser/net/url_request_mock_http_job.cc b/chrome/browser/net/url_request_mock_http_job.cc |
index f9feb1a34499083594ab7f0a5e67ece17b87ac3e..cad1a1ed6954989057891e26f48631eff09d2c16 100644 |
--- a/chrome/browser/net/url_request_mock_http_job.cc |
+++ b/chrome/browser/net/url_request_mock_http_job.cc |
@@ -70,7 +70,7 @@ FilePath URLRequestMockHTTPJob::GetOnDiskPath(const FilePath& base_path, |
URLRequestMockHTTPJob::URLRequestMockHTTPJob(net::URLRequest* request, |
const FilePath& file_path) |
- : URLRequestFileJob(request, file_path) { } |
+ : net::URLRequestFileJob(request, file_path) { } |
// Public virtual version. |
void URLRequestMockHTTPJob::GetResponseInfo(net::HttpResponseInfo* info) { |
@@ -80,8 +80,8 @@ void URLRequestMockHTTPJob::GetResponseInfo(net::HttpResponseInfo* info) { |
bool URLRequestMockHTTPJob::IsRedirectResponse(GURL* location, |
int* http_status_code) { |
// Override the URLRequestFileJob implementation to invoke the default one |
// based on HttpResponseInfo. |
return net::URLRequestJob::IsRedirectResponse(location, http_status_code); |
} |
@@ -80,8 +80,8 @@ void URLRequestMockHTTPJob::GetResponseInfo(net::HttpResponseInfo* info) { |
bool URLRequestMockHTTPJob::IsRedirectResponse(GURL* location, |
int* http_status_code) { |
- // Override the URLRequestFileJob implementation to invoke the default one |
- // based on HttpResponseInfo. |
+ // Override the net::URLRequestFileJob implementation to invoke the default |
+ // one based on HttpResponseInfo. |
return net::URLRequestJob::IsRedirectResponse(location, http_status_code); |
} |